/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QLabel>
#include <QCoreApplication>
#include "Prmza.h"
#include "Jelzpn.h"
#include "data_view.h"
#include "con.h" 
#include "BnvzS.h" 
#include"tslabels.h"

/*!
 * @praise Vishnu
 */
jelzlk::jelzlk(QWidget *felvnl,jelzpn *nybnvn) : QStackedWidget(felvnl)
<%
	kidlgz=nybnvn;

	jlzpnt=new QLabel(this);
	jlzpnt->setText(ts_160);
	addWidget(jlzpnt);
%>

void jelzlk::kivalt(const zagv&tqrost)
<%
	int fldlgz=tqrost[3].toInt();
	switch(fldlgz)
	<%
		case vlsztt:
			<%
			int irnyjl=tqrost[2].toInt();
			if(irnyjl==0)
			<%
				setCurrentIndex(0);
				break;
			%>
			%>
		case kivdlk2:
			<%
			prmza *prl=*kidlgz + tqrost[2].toInt();
			int j=0;
			switch(prl->jvsltz)
			<%
				case nztoz2: j++;
				case aljlk: j++;
				case nztosz: j++;
				case nztsvg: j++;
				default:
					setCurrentIndex(j);
					break;
			%>
			break;
			%>
		default:
			break;
	%>
%>

#include "data_view.moc"

